Stan Math Library: stan/math/rev/mat/fun/sd.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
sd.hpp File Reference
`#include <stan/math/prim/arr/err/check_nonzero_size.hpp>`
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/fun/mean.hpp>`
`#include <stan/math/rev/core.hpp>`
`#include <boost/math/tools/promotion.hpp>`
`#include <cmath>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
var | stan::math::sd (const std::vector< var > &v)
| Return the sample standard deviation of the specified standard vector. More...
template<int R, int C>
var | stan::math::sd (const Eigen::Matrix< var, R, C > &m)

[ Stan Home Page ] © 2011–2016, Stan Development Team.